brasero r1067 - in trunk: . src



Author: philippr
Date: Wed Aug 13 12:07:02 2008
New Revision: 1067
URL: http://svn.gnome.org/viewvc/brasero?rev=1067&view=rev

Log:
Forgotten entry in ChangeLog

Modified:
   trunk/ChangeLog
   trunk/src/brasero-data-disc.c
   trunk/src/brasero-drive-properties.c
   trunk/src/brasero-file-node.c
   trunk/src/brasero-file-node.h
   trunk/src/burn-job.c

Modified: trunk/src/brasero-data-disc.c
==============================================================================
--- trunk/src/brasero-data-disc.c	(original)
+++ trunk/src/brasero-data-disc.c	Wed Aug 13 12:07:02 2008
@@ -906,10 +906,10 @@
 					 _("Do you really want to add \"%s\" to the selection and use ISO9660 level 3 standard to support it?"),
 					 name);
 
-	gtk_window_set_title (GTK_WINDOW (dialog), _("File Over 2 Gio"));
+	gtk_window_set_title (GTK_WINDOW (dialog), _("File Over 2 GiB"));
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("The size of the file is over 2 Gio. This isn't supported by ISO9660 standard in his first and second versions (the most widespread ones)."
+						  _("The size of the file is over 2 GiB. This isn't supported by ISO9660 standard in his first and second versions (the most widespread ones)."
 						    "\nISO9660 level 3 standard is supported by most of the operating systems including linux and all versions of Windows Â. Therefore the burnt medium can be read by these operating systems."
 						    "\nA known exception is MacOS X that can't read images created with ISO9660 level 3 standard."));
 
@@ -1244,7 +1244,7 @@
 	if (brasero_data_project_is_joliet_compliant (priv->project))
 		fs_type |= BRASERO_IMAGE_FS_JOLIET;
 
-	if (stats->num_2Gio != 0)
+	if (stats->num_2GiB != 0)
 		fs_type |= BRASERO_IMAGE_ISO_FS_LEVEL_3|BRASERO_IMAGE_FS_UDF;
 
 	if (stats->num_deep != 0)

Modified: trunk/src/brasero-drive-properties.c
==============================================================================
--- trunk/src/brasero-file-node.c	(original)
+++ trunk/src/brasero-file-node.c	Wed Aug 13 12:07:02 2008
@@ -754,9 +754,9 @@
 		sectors = BRASERO_SIZE_TO_SECTORS (g_file_info_get_size (info), 2048);
 
 		if (sectors > BRASERO_FILE_2G_LIMIT && BRASERO_FILE_NODE_SECTORS (node) <= BRASERO_FILE_2G_LIMIT)
-			stats->num_2Gio ++;
+			stats->num_2GiB ++;
 		else if (sectors <= BRASERO_FILE_2G_LIMIT && BRASERO_FILE_NODE_SECTORS (node) > BRASERO_FILE_2G_LIMIT)
-			stats->num_2Gio --;
+			stats->num_2GiB --;
 
 		/* The node isn't grafted and it's a file. So we must propagate
 		 * its size up to the parent graft node. */
@@ -1015,9 +1015,9 @@
 
 	/* update all statistics on tree if any */
 	if (stats) {
-		/* check if that's a 2 Gio file */
-		if (node->is_2Gio)
-			stats->num_2Gio --;
+		/* check if that's a 2 GiB file */
+		if (node->is_2GiB)
+			stats->num_2GiB --;
 
 		/* check if that's a deep directory file */
 		if (node->is_deep)

Modified: trunk/src/brasero-file-node.h
==============================================================================
--- trunk/src/brasero-file-node.h	(original)
+++ trunk/src/brasero-file-node.h	Wed Aug 13 12:07:02 2008
@@ -61,13 +61,13 @@
  * NOTE: The root object keeps some statistics about its tree like
  * - number of children (files+directories)
  * - number of deep directories
- * - number of files over 2 Gio
+ * - number of files over 2 GiB
  */
 
 struct _BraseroFileTreeStats {
 	guint children;
 	guint num_deep;
-	guint num_2Gio;
+	guint num_2GiB;
 };
 typedef struct _BraseroFileTreeStats BraseroFileTreeStats;
 
@@ -99,9 +99,9 @@
 	/* NOTE: overflow for sectors will probably not be hit
 	 * before a few years given that we store the size in
 	 * sectors of 2048. For the time being DVD are usually
-	 * 4.3 Gio. To overflow the following member (provided
+	 * 4.3 GiB. To overflow the following member (provided
 	 * we are on a 32 architecture) they would have to be
-	 * over 8192 Gio. I think it's reasonable to think we
+	 * over 8192 GiB. I think it's reasonable to think we
 	 * have time. And even then, by this time most of the 
 	 * computers will have switched to 64 architecture (in
 	 * 2099) and I'll be dead anyway as well as optical
@@ -129,7 +129,7 @@
 	guint is_exploring:1;
 
 	/* that's for some special nodes (usually counted in statistics) */
-	guint is_2Gio:1;
+	guint is_2GiB:1;
 	guint is_deep:1;
 
 	/* This is for nodes created at project load time. This means

Modified: trunk/src/burn-job.c
==============================================================================
--- trunk/src/brasero-drive-properties.c	(original)
+++ trunk/src/brasero-drive-properties.c	Wed Aug 13 12:07:02 2008
@@ -178,8 +178,8 @@
 	 * get in out way. Think getrlimit (). */
 
 	/* check the filesystem type: the problem here is that some
 	 * filesystems have a maximum file size limit of 4 Gio and more than
 	 * often we need a temporary file size of 4 Gio or more. */
 	filesystem = g_file_info_get_attribute_string (info, G_FILE_ATTRIBUTE_FILESYSTEM_TYPE);
 	if (priv->check_filesystem
 	&&  filesystem
@@ -197,7 +197,7 @@
 						 _("Do you really want to choose this location?"));
 
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-							  _("The filesystem on this volume doesn't support large files (size over 2 Gio)."
+							  _("The filesystem on this volume doesn't support large files (size over 2 GiB)."
 							    "\nThis can be a problem when writing DVDs or large images."));
 
 		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
@@ -178,8 +178,8 @@
 
 	/* check the filesystem type: the problem here is that some
-	 * filesystems have a maximum file size limit of 4 Gio and more than
-	 * often we need a temporary file size of 4 Gio or more. */
+	 * filesystems have a maximum file size limit of 4 GiB and more than
+	 * often we need a temporary file size of 4 GiB or more. */
 	filesystem = g_file_info_get_attribute_string (info, G_FILE_ATTRIBUTE_FILESYSTEM_TYPE);
 	if (priv->check_filesystem

Modified: trunk/src/brasero-file-node.c
==============================================================================
--- trunk/src/burn-job.c	(original)
+++ trunk/src/burn-job.c	Wed Aug 13 12:07:02 2008
@@ -461,8 +461,8 @@
 	brasero_job_get_session_output_size (BRASERO_JOB (self), NULL, &output_size);
 
 	/* Now check the filesystem type: the problem here is that some
 	 * filesystems have a maximum file size limit of 4 Gio and more than
 	 * often we need a temporary file size of 4 Gio or more. */
 	filesystem = g_file_info_get_attribute_string (info, G_FILE_ATTRIBUTE_FILESYSTEM_TYPE);
 	BRASERO_BURN_LOG ("%s filesystem detected", filesystem);
 
@@ -477,7 +477,7 @@
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_DISK_SPACE,
-			     _("The filesystem you chose to store the temporary image on cannot hold files with a size over 2 Gio."));
+			     _("The filesystem you chose to store the temporary image on cannot hold files with a size over 2 GiB."));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -461,8 +461,8 @@
 
 	/* Now check the filesystem type: the problem here is that some
-	 * filesystems have a maximum file size limit of 4 Gio and more than
-	 * often we need a temporary file size of 4 Gio or more. */
+	 * filesystems have a maximum file size limit of 4 GiB and more than
+	 * often we need a temporary file size of 4 GiB or more. */
 	filesystem = g_file_info_get_attribute_string (info, G_FILE_ATTRIBUTE_FILESYSTEM_TYPE);
 	BRASERO_BURN_LOG ("%s filesystem detected", filesystem);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]